/*
** Module   : FieldInterface.java
** Abstract : interface which must be extended by FieldReference
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 VMN 20130207 Created initial version.
** 002 VMN 20130217 Extended from DatabaseInfo and added support for attributes
**                  BUFFER-NAME (KW_BUF_NAME),
**                  LITERAL-QUESTION (KW_LIT_QSTN)
**                  VALIDATE-MESSAGE (KW_VAL_MSG)
**                  MANDATORY (KW_MAND)
**                  VALIDATE-EXPRESSION (KW_VAL_EXPR)
*/

package com.goldencode.p2j.persist;

import com.goldencode.p2j.util.*;

/**
 * Defines the public API for services representing Progress builtin functions, methods,
 * attributes, and language statements, which operate on fields.
 */
public interface FieldInterface
extends DatabaseInfo,
        WidthCharable
{
   /**
    * Conversion of EXTENT attribute (KW_EXTENT).
    *
    * Getter of EXTENT attribute
    *
    */
   public integer extent();

   /**
    * Conversion of FORMAT attribute (KW_FORMAT).
    *
    * Getter of FORMAT attribute.
    *
    * @return  current value of FORMAT attribute.
    */
   public character format();

   /**
    * Conversion of FORMAT attribute (KW_FORMAT).
    *
    * Setter of FORMAT attribute.
    *
    */
   public void changeFormat(character format);

   /**
    * Conversion of STRING-VALUE attribute (KW_STR_VAL).
    *
    * Getter of STRING-VALUE attribute.
    *
    * @return  current value of STRING-VALUE attribute.
    */
   public character stringValue();

   /**
    * Conversion of STRING-VALUE attribute (KW_STR_VAL).
    *
    * Getter of STRING-VALUE attribute.
    *
    * @param   index
    *          An integer expression representing a subscript, for fields that have extents.
    *
    * @return  current value of STRING-VALUE attribute.
    */
   public character stringValue(int index);

   /**
    * Conversion of BUFFER-VALUE attribute (KW_BUF_VAL).
    *
    * Getter of current value of a buffer-field object. If you modify the BUFFER-VALUE attribute,
    * Progress sets the buffer-field object to the new value.
    *
    * @param   index
    *          An INTEGER expression representing a subscript, for fields that have extents.
    *
    * @return  current value of a buffer-field object.
    */
   public Object value(int index);

   /**
    * Conversion of BUFFER-VALUE attribute (KW_BUF_VAL).
    *
    * Setter of current value of a buffer-field object. If you modify the BUFFER-VALUE attribute,
    * Progress sets the buffer-field object to the new value.
    *
    * @param   index
    *          An INTEGER expression representing a subscript, for fields that have extents.
    * @param   dmo
    *          New value of a buffer-field object.
    *
    */
   public void changeValue(int index, Object dmo);

   /**
    * Conversion of BUFFER-VALUE attribute (KW_BUF_VAL).
    *
    * Getter of current value of a buffer-field object. If you modify the BUFFER-VALUE attribute,
    * Progress sets the buffer-field object to the new value.
    *
    * @return  current value of a buffer-field object.
    */
   public Object value();

   /**
    * Conversion of BUFFER-VALUE attribute (KW_BUF_VAL).
    *
    * Setter of current value of a buffer-field object. If you modify the BUFFER-VALUE attribute,
    * Progress sets the buffer-field object to the new value.
    *
    * @param   dmo
    *          New value of a buffer-field object.
    *
    */
   public void changeValue(Object dmo);

   /**
    * Conversion of COLUMN-LABEL attribute (KW_COL_LAB).
    *
    * Getter of COLUMN-LABEL attribute.
    *
    * @return  current value of COLUMN-LABEL attribute.
    */
   public character columnLabel();

   /**
    * Conversion of COLUMN-LABEL attribute (KW_COL_LAB).
    *
    * Getter of COLUMN-LABEL attribute.

    * @param   columnLabel
    *          New value of a attribute.
    */
   public void changeColumnLabel(character columnLabel);

   /**
    * Conversion of BUFFER-NAME attribute (KW_BUF_NAME).
    *
    * Gets the name of the buffer object to which the buffer-field object belongs.
    *
    * @return  name of the buffer object to which the buffer-field object belongs.
    */
   public character bufferName();

   /**
    * Conversion of LITERAL-QUESTION attribute (KW_LIT_QSTN).
    *
    * Getter of LITERAL-QUESTION attribute.
    *
    * @return  current value of LITERAL-QUESTION attribute.
    */
   public logical literalQuestion();

   /**
    * Conversion of LITERAL-QUESTION attribute (KW_LIT_QSTN).
    *
    * Setter of LITERAL-QUESTION attribute.
    *
    * @param   literalQuestion
    *          New value of LITERAL-QUESTION attribute.
    */
   public void changeLiteralQuestion(logical literalQuestion);

   /**
    * Conversion of VALIDATE-MESSAGE attribute (KW_VAL_MSG).
    *
    * Getter of VALIDATE-MESSAGE attribute.
    *
    * @return  current value of VALIDATE-MESSAGE attribute.
    */
   public character validateMessage();

   /**
    * Conversion of VALIDATE-MESSAGE attribute (KW_VAL_MSG).
    *
    * Setter of VALIDATE-MESSAGE attribute.
    *
    * @param   validateMessage
    *          New value of VALIDATE-MESSAGE attribute.
    */
   public void changeValidateMessage(character validateMessage);

   /**
    * Conversion of MANDATORY attribute (KW_MAND).
    *
    * Getter of KW_MAND attribute.
    *
    * @return current value of KW_MAND attribute.
    */
   public logical mandatory();

   /**
    * Conversion of VALIDATE-EXPRESSION attribute (KW_VAL_EXPR).
    *
    * Getter of VALIDATE-EXPRESSION attribute.
    *
    * @return current value of VALIDATE-EXPRESSION attribute.
    */
   public character validateExpression();

   /**
    * Conversion of VALIDATE-EXPRESSION attribute (KW_VAL_EXPR).
    *
    * Setter of VALIDATE-EXPRESSION attribute.
    *
    * @param  validateExpression
    *         New value of VALIDATE-EXPRESSION attribute.
    */
   public void changeValidateExpression(character validateExpression);

}
